@@ -11,6 +11,8 @@ import pandas as pd
 import requests
 from retrying import retry
 
+from polly import constants as const
+
 from polly import helpers
 from polly.auth import Polly
 from polly.constants import DATA_TYPES
@@ -24,6 +26,7 @@ from polly.errors import (
     wrongParamException,
     apiErrorException,
     invalidApiResponseException,
+    invalidDataException,
 )
 from deprecated import deprecated
 from polly.index_schema_level_conversion_const import indexes_schema_level_map
@@ -56,6 +59,12 @@ class OmixAtlas:
         error_handler(response)
         return response.json()
 
+    def get_omixatlas(self, key: str):
+        url = f"{self.resource_url}/{key}"
+        response = self.session.get(url)
+        error_handler(response)
+        return response.json()
+
     def query_metadata(
         self,
         query: str,
@@ -514,7 +523,9 @@ class OmixAtlas:
                       'Datatype': datatype_list,
                       'Field Name':field_name_list,
                       'Field Description':field_desc_list,
-                      'Field Type': field_type_list
+                      'Field Type': field_type_list,
+                      'Is Curated': curated_bool_val,
+                      'Is Array': is_array_bool_value,
                   }
 
         """
@@ -524,6 +535,8 @@ class OmixAtlas:
         field_name_list = []
         field_description_list = []
         field_type_list = []
+        is_curated_list = []
+        is_array_list = []
         for outer_key, inner_dict_datatype in nested_schema_dict.items():
             for middle_key, inner_dict_fields in inner_dict_datatype.items():
                 for inner_key, field_values in inner_dict_fields.items():
@@ -535,12 +548,20 @@ class OmixAtlas:
                             field_description_list.append(field_values[key])
                         if key == "type":
                             field_type_list.append(field_values[key])
+                        if key == "is_curated":
+                            is_curated_list.append(field_values[key])
+                        if key == "is_array":
+                            is_array_list.append(field_values[key])
 
         reformed_dict["Source"] = source_list
         reformed_dict["Datatype"] = data_type_list
         reformed_dict["Field Name"] = field_name_list
         reformed_dict["Field Description"] = field_description_list
         reformed_dict["Field Type"] = field_type_list
+        if is_curated_list:
+            reformed_dict["Is Curated"] = is_curated_list
+        reformed_dict["Is Array"] = is_array_list
+
         return reformed_dict
 
     def nested_dict_to_df(self, schema_dict: dict) -> pd.DataFrame:
@@ -638,14 +659,6 @@ class OmixAtlas:
                 detail="Params are either empty or its datatype is not correct",
             )
 
-    # ? DEPRECATED
-    def search_metadata(self, query: dict):
-        url = f"{self.resource_url}/_search"
-        payload = query
-        response = self.session.get(url, json=payload)
-        error_handler(response)
-        return response.json()
-
     def download_data(self, repo_name, _id: str):
         url = f"{self.resource_url}/{repo_name}/download"
         params = {"_id": _id}
@@ -740,6 +753,216 @@ class OmixAtlas:
         logging.basicConfig(level=logging.INFO)
         logging.info("File converted successfully!")
 
+    def create(
+        self,
+        display_name: str,
+        description: str,
+        repo_name="",
+        image_url="",
+        components=[],
+    ) -> pd.DataFrame:
+        """
+        This function is used to create a new omixatlas
+        Args:
+            | display_name(str): display name of the omixatlas
+            | description(str): description of the omixatlas
+            | repo_name(str): repo_name which is used to create index in db
+            | image_url(str): Url of the icon for omixatlas. Optional Parameter
+            | initials(str): Initials shown in the icon of omixatlas. Optional Parameter
+            | explorer_enabled(bool): Default True. Optional Parameter
+            | studio_presets(list): Optional Paramter
+            | components(list): Optional Parameter
+        Returns:
+            | Dataframe after creation of omixatlas
+        """
+        payload = self._get_repository_payload()
+        frontend_info = {}
+        frontend_info["description"] = description
+        frontend_info["display_name"] = display_name
+        frontend_info["icon_image_url"] = (
+            image_url if image_url else const.IMAGE_URL_ENDPOINT
+        )
+
+        if not repo_name:
+            repo_name = self._create_repo_name(display_name)
+        else:
+            repo_name = repo_name
+
+        payload["data"]["attributes"]["repo_name"] = repo_name
+        payload["data"]["attributes"]["frontend_info"] = frontend_info
+        payload["data"]["attributes"]["components"] = components
+        indexes = payload["data"]["attributes"]["indexes"]
+
+        for key in indexes.keys():
+            indexes[key] = f"{repo_name}_{key}"
+
+        repository_url = f"{self.resource_url}"
+        resp = self.session.post(repository_url, json=payload)
+        error_handler(resp)
+
+        if resp.status_code != const.CREATED:
+            raise Exception(resp.text)
+        else:
+            if resp.json()["data"]["id"]:
+                repo_id = resp.json()["data"]["id"]
+                print(f" OmixAtlas {repo_id} Created  ")
+                return self._repo_creation_response_df(resp.json())
+            else:
+                ValueError("Repository creation response is in Incorrect format")
+
+    def update(
+        self,
+        repo_key: str,
+        display_name="",
+        description="",
+        image_url="",
+        components=[],
+    ) -> pd.DataFrame:
+        """
+        This function is used to update an omixatlas
+        Args:
+            | repo_name(str/int): repo_name/repo_id for that Omixatlas
+            | display_name(str): display name of the omixatlas. Optional Parameter
+            | description(str): description of the omixatlas. Optional Parameter
+            | image_url(str): Url of the icon for omixatlas. Optional Parameter
+            | components(list): List of components to be added. Optional Parameter
+        """
+
+        if not (repo_key and (isinstance(repo_key, str) or isinstance(repo_key, int))):
+            raise InvalidParameterException("repo_id/repo_name")
+
+        if not display_name and not description and not image_url and not components:
+            raise paramException(
+                title="Param Error",
+                detail="No params passed to update, please pass a param",
+            )
+
+        if isinstance(repo_key, int):
+            repo_key = str(repo_key)
+
+        repo_curr_data = self.get_omixatlas(repo_key)
+
+        if "attributes" not in repo_curr_data["data"]:
+            raise invalidDataException(
+                detail="OmixAtlas is not created properly. Please contact admin"
+            )
+
+        attribute_curr_data = repo_curr_data["data"]["attributes"]
+        if components:
+            curr_components = attribute_curr_data.get("components", [])
+            for item in components:
+                curr_components.append(item)
+
+        repo_curr_data["data"]["attributes"] = attribute_curr_data
+
+        if "frontend_info" not in repo_curr_data["data"]["attributes"]:
+            raise invalidDataException(
+                detail="OmixAtlas is not created properly. Please contact admin"
+            )
+
+        frontendinfo_curr_data = repo_curr_data["data"]["attributes"]["frontend_info"]
+        repo_curr_data["data"]["attributes"][
+            "frontend_info"
+        ] = self._update_frontendinfo_value(
+            frontendinfo_curr_data, image_url, description, display_name
+        )
+
+        repository_url = f"{self.resource_url}/{repo_key}"
+        resp = self.session.patch(repository_url, json=repo_curr_data)
+        error_handler(resp)
+        if resp.status_code != const.OK:
+            raise Exception(resp.text)
+        else:
+            if resp.json()["data"]["id"]:
+                repo_id = resp.json()["data"]["id"]
+                print(f" OmixAtlas {repo_id} Updated  ")
+                return self._repo_creation_response_df(resp.json())
+            else:
+                ValueError("Repository Updation response is in Incorrect format")
+
+    def _update_frontendinfo_value(
+        self,
+        frontendinfo_curr_data: dict,
+        image_url: str,
+        description: str,
+        display_name: str,
+    ) -> dict:
+        if image_url:
+            frontendinfo_curr_data["icon_image_url"] = image_url
+        if description:
+            frontendinfo_curr_data["description"] = description
+        if display_name:
+            frontendinfo_curr_data["display_name"] = display_name
+        return frontendinfo_curr_data
+
+    def _repo_creation_response_df(self, original_response) -> pd.DataFrame:
+        """
+        This function is used to create dataframe from json reponse of
+        creation api
+
+        Args:
+            | original response(dict): creation api response
+        Returns:
+            | DataFrame consisting of 4 columns ["Repository Id", "Repository Name", "Display Name", "Description"]
+
+        """
+        response_df_dict = {}
+        if original_response["data"]:
+            if original_response["data"]["attributes"]:
+                attribute_data = original_response["data"]["attributes"]
+                response_df_dict["Repository Id"] = attribute_data.get("repo_id", "")
+                response_df_dict["Repository Name"] = attribute_data.get(
+                    "repo_name", ""
+                )
+                if attribute_data["frontend_info"]:
+                    front_info_dict = attribute_data["frontend_info"]
+                    response_df_dict["Display Name"] = front_info_dict.get(
+                        "display_name", ""
+                    )
+                    response_df_dict["Description"] = front_info_dict.get(
+                        "description", ""
+                    )
+        rep_creation_df = pd.DataFrame([response_df_dict])
+        return rep_creation_df
+
+    def _create_repo_name(self, display_name) -> str:
+        """
+        This function is used to repo_name from display_name
+        Args:
+            | display_name(str): display name of the omixatlas
+        Returns:
+            | Constructed repo name
+        """
+        repo_name = display_name.lower().replace(" ", "_")
+        return repo_name
+
+    def _get_repository_payload(self):
+        """ """
+        return {
+            "data": {
+                "type": "repositories",
+                "attributes": {
+                    "frontend_info": {
+                        "description": "<DESCRIPTION>",
+                        "display_name": "<REPO_DISPLAY_NAME>",
+                        "explorer_enabled": True,
+                        "initials": "<INITIALS>",
+                    },
+                    "indexes": {
+                        "csv": "<REPO_NAME>_csv",
+                        "files": "<REPO_NAME>_files",
+                        "gct_data": "<REPO_NAME>_gct_data",
+                        "gct_metadata": "<REPO_NAME>_gct_metadata",
+                        "h5ad_data": "<REPO_NAME>_h5ad_data",
+                        "h5ad_metadata": "<REPO_NAME>_h5ad_metadata",
+                        "ipynb": "<REPO_NAME>_ipynb",
+                        "json": "<REPO_NAME>_json",
+                    },
+                    "repo_name": "<REPO_NAME>",
+                },
+            }
+        }
+
 
 if __name__ == "__main__":
     client = OmixAtlas()
